@@ -121,7 +121,7 @@ pub trait VirtualFileSystem: Debug+Send+Sync+'static
     ///
     /// let vfs = Vfs::memfs();
     /// let file = vfs.root().mash("file");
-    /// let mut f = vfs.create(&file).unwrap();
+    /// let mut f = vfs.write(&file).unwrap();
     /// f.write_all(b"foobar").unwrap();
     /// f.flush().unwrap();
     /// let mut f = vfs.append(&file).unwrap();
@@ -281,28 +281,6 @@ pub trait VirtualFileSystem: Debug+Send+Sync+'static
     /// ```
     fn copy_b<T: AsRef<Path>, U: AsRef<Path>>(&self, src: T, dst: U) -> RvResult<Copier>;
 
-    /// Opens a file in write-only mode
-    ///
-    /// * Creates a file if it does not exist or truncates it if it does
-    ///
-    /// ### Errors
-    /// * PathError::IsNotDir(PathBuf) when the given path's parent exists but is not a directory
-    /// * PathError::DoesNotExist(PathBuf) when the given path's parent doesn't exist
-    /// * PathError::IsNotFile(PathBuf) when the given path exists but is not a file
-    ///
-    /// ### Examples
-    /// ```
-    /// use rivia::prelude::*;
-    ///
-    /// let vfs = Vfs::memfs();
-    /// let file = vfs.root().mash("file");
-    /// let mut f = vfs.create(&file).unwrap();
-    /// f.write_all(b"foobar").unwrap();
-    /// f.flush().unwrap();
-    /// assert_vfs_read_all!(vfs, &file, "foobar");
-    /// ```
-    fn create<T: AsRef<Path>>(&self, path: T) -> RvResult<Box<dyn Write>>;
-
     /// Returns the current working directory
     ///
     /// ### Examples
@@ -670,29 +648,6 @@ pub trait VirtualFileSystem: Debug+Send+Sync+'static
     /// ```
     fn move_p<T: AsRef<Path>, U: AsRef<Path>>(&self, src: T, dst: U) -> RvResult<()>;
 
-    /// Attempts to open a file in readonly mode
-    ///
-    /// * Provides a handle to a Read + Seek implementation
-    /// * Handles path expansion and absolute path resolution
-    ///
-    /// ### Errors
-    /// * PathError::IsNotFile(PathBuf) when the given path isn't a file
-    /// * PathError::DoesNotExist(PathBuf) when the given path doesn't exist
-    ///
-    /// ### Examples
-    /// ```
-    /// use rivia::prelude::*;
-    ///
-    /// let vfs = Vfs::memfs();
-    /// let file = vfs.root().mash("file");
-    /// assert_vfs_write_all!(vfs, &file, b"foobar 1");
-    /// let mut file = vfs.open(&file).unwrap();
-    /// let mut buf = String::new();
-    /// file.read_to_string(&mut buf);
-    /// assert_eq!(buf, "foobar 1".to_string());
-    /// ```
-    fn open<T: AsRef<Path>>(&self, path: T) -> RvResult<Box<dyn ReadSeek>>;
-
     /// Returns the (user ID, group ID) of the owner of this file
     ///
     /// * Handles path expansion and absolute path resolution
@@ -728,6 +683,29 @@ pub trait VirtualFileSystem: Debug+Send+Sync+'static
     /// ```
     fn paths<T: AsRef<Path>>(&self, path: T) -> RvResult<Vec<PathBuf>>;
 
+    /// Open a file in readonly mode
+    ///
+    /// * Provides a handle to a Read + Seek implementation
+    /// * Handles path expansion and absolute path resolution
+    ///
+    /// ### Errors
+    /// * PathError::IsNotFile(PathBuf) when the given path isn't a file
+    /// * PathError::DoesNotExist(PathBuf) when the given path doesn't exist
+    ///
+    /// ### Examples
+    /// ```
+    /// use rivia::prelude::*;
+    ///
+    /// let vfs = Vfs::memfs();
+    /// let file = vfs.root().mash("file");
+    /// assert_vfs_write_all!(vfs, &file, b"foobar 1");
+    /// let mut file = vfs.read(&file).unwrap();
+    /// let mut buf = String::new();
+    /// file.read_to_string(&mut buf);
+    /// assert_eq!(buf, "foobar 1".to_string());
+    /// ```
+    fn read<T: AsRef<Path>>(&self, path: T) -> RvResult<Box<dyn ReadSeek>>;
+
     /// Read all data from the given file and return it as a String
     ///
     /// * Handles path expansion and absolute path resolution
@@ -747,6 +725,25 @@ pub trait VirtualFileSystem: Debug+Send+Sync+'static
     /// ```
     fn read_all<T: AsRef<Path>>(&self, path: T) -> RvResult<String>;
 
+    /// Read the given file and returns it as lines in a vector
+    ///
+    /// * Handles path expansion and absolute path resolution
+    ///
+    /// ### Errors
+    /// * PathError::IsNotFile(PathBuf) when the given path isn't a file
+    /// * PathError::DoesNotExist(PathBuf) when the given path doesn't exist
+    ///
+    /// ### Examples
+    /// ```
+    /// use rivia::prelude::*;
+    ///
+    /// let vfs = Vfs::memfs();
+    /// let file = vfs.root().mash("file");
+    /// assert_vfs_write_all!(vfs, &file, "1\n2");
+    /// assert_eq!(vfs.read_lines(&file).unwrap(), vec!["1".to_string(), "2".to_string()]);
+    /// ```
+    fn read_lines<T: AsRef<Path>>(&self, path: T) -> RvResult<Vec<String>>;
+
     /// Returns the relative path of the target the link points to
     ///
     /// * Handles path expansion and absolute path resolution
@@ -905,6 +902,28 @@ pub trait VirtualFileSystem: Debug+Send+Sync+'static
     /// ```
     fn upcast(self) -> Vfs;
 
+    /// Opens a file in write-only mode
+    ///
+    /// * Creates a file if it does not exist or truncates it if it does
+    ///
+    /// ### Errors
+    /// * PathError::IsNotDir(PathBuf) when the given path's parent exists but is not a directory
+    /// * PathError::DoesNotExist(PathBuf) when the given path's parent doesn't exist
+    /// * PathError::IsNotFile(PathBuf) when the given path exists but is not a file
+    ///
+    /// ### Examples
+    /// ```
+    /// use rivia::prelude::*;
+    ///
+    /// let vfs = Vfs::memfs();
+    /// let file = vfs.root().mash("file");
+    /// let mut f = vfs.write(&file).unwrap();
+    /// f.write_all(b"foobar").unwrap();
+    /// f.flush().unwrap();
+    /// assert_vfs_read_all!(vfs, &file, "foobar");
+    /// ```
+    fn write<T: AsRef<Path>>(&self, path: T) -> RvResult<Box<dyn Write>>;
+
     /// Write the given data to to the target file
     ///
     /// * Handles path expansion and absolute path resolution
@@ -927,6 +946,29 @@ pub trait VirtualFileSystem: Debug+Send+Sync+'static
     /// assert_vfs_read_all!(vfs, &file, "foobar 1");
     /// ```
     fn write_all<T: AsRef<Path>, U: AsRef<[u8]>>(&self, path: T, data: U) -> RvResult<()>;
+
+    /// Write the given lines to to the target file
+    ///
+    /// * Handles path expansion and absolute path resolution
+    /// * Create the file first if it doesn't exist or truncating it first if it does
+    ///
+    /// ### Errors
+    /// * PathError::IsNotDir(PathBuf) when the given path's parent exists but is not a directory
+    /// * PathError::DoesNotExist(PathBuf) when the given path's parent doesn't exist
+    /// * PathError::IsNotFile(PathBuf) when the given path exists but is not a file
+    ///
+    /// ### Examples
+    /// ```
+    /// use rivia::prelude::*;
+    ///
+    /// let vfs = Vfs::memfs();
+    /// let file = vfs.root().mash("file");
+    /// assert_vfs_no_file!(vfs, &file);
+    /// assert!(vfs.write_lines(&file, &["1", "2"]).is_ok());
+    /// assert_vfs_is_file!(vfs, &file);
+    /// assert_vfs_read_all!(vfs, &file, "1\n2".to_string());
+    /// ```
+    fn write_lines<T: AsRef<Path>, U: AsRef<str>>(&self, path: T, lines: &[U]) -> RvResult<()>;
 }
 
 /// Provides an ergonomic encapsulation of the underlying [`VirtualFileSystem`] backend
@@ -1095,7 +1137,7 @@ impl VirtualFileSystem for Vfs
     ///
     /// let vfs = Vfs::memfs();
     /// let file = vfs.root().mash("file");
-    /// let mut f = vfs.create(&file).unwrap();
+    /// let mut f = vfs.write(&file).unwrap();
     /// f.write_all(b"foobar").unwrap();
     /// f.flush().unwrap();
     /// let mut f = vfs.append(&file).unwrap();
@@ -1303,34 +1345,6 @@ impl VirtualFileSystem for Vfs
         }
     }
 
-    /// Opens a file in write-only mode
-    ///
-    /// * Creates a file if it does not exist or truncates it if it does
-    ///
-    /// ### Errors
-    /// * PathError::IsNotDir(PathBuf) when the given path's parent exists but is not a directory
-    /// * PathError::DoesNotExist(PathBuf) when the given path's parent doesn't exist
-    /// * PathError::IsNotFile(PathBuf) when the given path exists but is not a file
-    ///
-    /// ### Examples
-    /// ```
-    /// use rivia::prelude::*;
-    ///
-    /// let vfs = Vfs::memfs();
-    /// let file = vfs.root().mash("file");
-    /// let mut f = vfs.create(&file).unwrap();
-    /// f.write_all(b"foobar").unwrap();
-    /// f.flush().unwrap();
-    /// assert_vfs_read_all!(vfs, &file, "foobar");
-    /// ```
-    fn create<T: AsRef<Path>>(&self, path: T) -> RvResult<Box<dyn Write>>
-    {
-        match self {
-            Vfs::Stdfs(x) => x.create(path),
-            Vfs::Memfs(x) => x.create(path),
-        }
-    }
-
     /// Returns the current working directory
     ///
     /// ### Examples
@@ -1816,35 +1830,6 @@ impl VirtualFileSystem for Vfs
         }
     }
 
-    /// Attempts to open a file in readonly mode
-    ///
-    /// * Provides a handle to a Read + Seek implementation
-    /// * Handles path expansion and absolute path resolution
-    ///
-    /// ### Errors
-    /// * PathError::IsNotFile(PathBuf) when the given path isn't a file
-    /// * PathError::DoesNotExist(PathBuf) when the given path doesn't exist
-    ///
-    /// ### Examples
-    /// ```
-    /// use rivia::prelude::*;
-    ///
-    /// let vfs = Vfs::memfs();
-    /// let file = vfs.root().mash("file");
-    /// assert_vfs_write_all!(vfs, &file, b"foobar 1");
-    /// let mut file = vfs.open(&file).unwrap();
-    /// let mut buf = String::new();
-    /// file.read_to_string(&mut buf);
-    /// assert_eq!(buf, "foobar 1".to_string());
-    /// ```
-    fn open<T: AsRef<Path>>(&self, path: T) -> RvResult<Box<dyn ReadSeek>>
-    {
-        match self {
-            Vfs::Stdfs(x) => x.open(path),
-            Vfs::Memfs(x) => x.open(path),
-        }
-    }
-
     /// Returns the (user ID, group ID) of the owner of this file
     ///
     /// * Handles path expansion and absolute path resolution
@@ -1892,6 +1877,35 @@ impl VirtualFileSystem for Vfs
         }
     }
 
+    /// Open a file in readonly mode
+    ///
+    /// * Provides a handle to a Read + Seek implementation
+    /// * Handles path expansion and absolute path resolution
+    ///
+    /// ### Errors
+    /// * PathError::IsNotFile(PathBuf) when the given path isn't a file
+    /// * PathError::DoesNotExist(PathBuf) when the given path doesn't exist
+    ///
+    /// ### Examples
+    /// ```
+    /// use rivia::prelude::*;
+    ///
+    /// let vfs = Vfs::memfs();
+    /// let file = vfs.root().mash("file");
+    /// assert_vfs_write_all!(vfs, &file, b"foobar 1");
+    /// let mut file = vfs.read(&file).unwrap();
+    /// let mut buf = String::new();
+    /// file.read_to_string(&mut buf);
+    /// assert_eq!(buf, "foobar 1".to_string());
+    /// ```
+    fn read<T: AsRef<Path>>(&self, path: T) -> RvResult<Box<dyn ReadSeek>>
+    {
+        match self {
+            Vfs::Stdfs(x) => x.read(path),
+            Vfs::Memfs(x) => x.read(path),
+        }
+    }
+
     /// Re/// Read all data from the given file and return it as a String
     ///
     /// * Handles path expansion and absolute path resolution
@@ -1917,6 +1931,31 @@ impl VirtualFileSystem for Vfs
         }
     }
 
+    /// Read the given file and returns it as lines in a vector
+    ///
+    /// * Handles path expansion and absolute path resolution
+    ///
+    /// ### Errors
+    /// * PathError::IsNotFile(PathBuf) when the given path isn't a file
+    /// * PathError::DoesNotExist(PathBuf) when the given path doesn't exist
+    ///
+    /// ### Examples
+    /// ```
+    /// use rivia::prelude::*;
+    ///
+    /// let vfs = Vfs::memfs();
+    /// let file = vfs.root().mash("file");
+    /// assert_vfs_write_all!(vfs, &file, "1\n2");
+    /// assert_eq!(vfs.read_lines(&file).unwrap(), vec!["1".to_string(), "2".to_string()]);
+    /// ```
+    fn read_lines<T: AsRef<Path>>(&self, path: T) -> RvResult<Vec<String>>
+    {
+        match self {
+            Vfs::Stdfs(x) => x.read_lines(path),
+            Vfs::Memfs(x) => x.read_lines(path),
+        }
+    }
+
     /// Returns the relative path of the target the link points to
     ///
     /// * Handles path expansion and absolute path resolution
@@ -2111,6 +2150,34 @@ impl VirtualFileSystem for Vfs
         }
     }
 
+    /// Opens a file in write-only mode
+    ///
+    /// * Creates a file if it does not exist or truncates it if it does
+    ///
+    /// ### Errors
+    /// * PathError::IsNotDir(PathBuf) when the given path's parent exists but is not a directory
+    /// * PathError::DoesNotExist(PathBuf) when the given path's parent doesn't exist
+    /// * PathError::IsNotFile(PathBuf) when the given path exists but is not a file
+    ///
+    /// ### Examples
+    /// ```
+    /// use rivia::prelude::*;
+    ///
+    /// let vfs = Vfs::memfs();
+    /// let file = vfs.root().mash("file");
+    /// let mut f = vfs.write(&file).unwrap();
+    /// f.write_all(b"foobar").unwrap();
+    /// f.flush().unwrap();
+    /// assert_vfs_read_all!(vfs, &file, "foobar");
+    /// ```
+    fn write<T: AsRef<Path>>(&self, path: T) -> RvResult<Box<dyn Write>>
+    {
+        match self {
+            Vfs::Stdfs(x) => x.write(path),
+            Vfs::Memfs(x) => x.write(path),
+        }
+    }
+
     /// Write the given data to to the target file
     ///
     /// * Handles path expansion and absolute path resolution
@@ -2140,6 +2207,35 @@ impl VirtualFileSystem for Vfs
         }
     }
 
+    /// Write the given lines to to the target file
+    ///
+    /// * Handles path expansion and absolute path resolution
+    /// * Create the file first if it doesn't exist or truncating it first if it does
+    ///
+    /// ### Errors
+    /// * PathError::IsNotDir(PathBuf) when the given path's parent exists but is not a directory
+    /// * PathError::DoesNotExist(PathBuf) when the given path's parent doesn't exist
+    /// * PathError::IsNotFile(PathBuf) when the given path exists but is not a file
+    ///
+    /// ### Examples
+    /// ```
+    /// use rivia::prelude::*;
+    ///
+    /// let vfs = Vfs::memfs();
+    /// let file = vfs.root().mash("file");
+    /// assert_vfs_no_file!(vfs, &file);
+    /// assert!(vfs.write_lines(&file, &["1", "2"]).is_ok());
+    /// assert_vfs_is_file!(vfs, &file);
+    /// assert_vfs_read_all!(vfs, &file, "1\n2".to_string());
+    /// ```
+    fn write_lines<T: AsRef<Path>, U: AsRef<str>>(&self, path: T, lines: &[U]) -> RvResult<()>
+    {
+        match self {
+            Vfs::Stdfs(x) => x.write_lines(path, lines),
+            Vfs::Memfs(x) => x.write_lines(path, lines),
+        }
+    }
+
     /// Up cast the trait type to the enum wrapper
     ///
     /// ### Examples
